==> haskell-citeproc-0.8.1-188-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-citeproc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 citeproc
version:              0.8.1
visibility:           public
id:                   citeproc-0.8.1-DCYulMz9O76CBUKZPEdQba
key:                  citeproc-0.8.1-DCYulMz9O76CBUKZPEdQba
license:              BSD-2-Clause
copyright:            2020 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Generates citations and bibliography from CSL styles.
description:
    citeproc parses CSL style files and uses them to
    generate a list of formatted citations and bibliography
    entries.  For more information about CSL, see
    <https://citationstyles.org/>.

category:             Text
abi:                  0ab8d7052c8f0ecf51ab84f7cafc391b
exposed:              True
exposed-modules:
    Citeproc Citeproc.CaseTransform Citeproc.CslJson Citeproc.Eval
    Citeproc.Locale Citeproc.Pandoc Citeproc.Style Citeproc.Types

hidden-modules:       Citeproc.Element Citeproc.Data Citeproc.Unicode
import-dirs:          /usr/lib/ghc-9.4.8/site-local/citeproc-0.8.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/citeproc-0.8.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/citeproc-0.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-citeproc
hs-libraries:         HSciteproc-0.8.1-DCYulMz9O76CBUKZPEdQba
depends:
    aeson-2.1.2.1-1sit77W6SL3BciMFQH0A5E
    attoparsec-0.14.4-6t7vY6Q8UUxCr7xgApY0J0 base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-KKJyu9JGFWV4kYAUCco28N
    containers-0.6.7 data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    pandoc-types-1.23.1-2Ru4LSPYtrN5GAW6c2x28j
    safe-0.3.21-EVxU3guTVsn44meiNlrghU
    scientific-0.3.7.0-BwEO4QQ4poVHhQfhShWbCU text-2.0.2
    text-icu-0.8.0.5-2r7xk6LESdq60514Vgauit transformers-0.5.6.2
    unicode-collation-0.1.3.6-DrJxI1kjQML5j1gAwZtrv
    uniplate-1.6.13-EDMgBXQkmI8BXGn3V0USux
    vector-0.13.2.0-7SxE3dSPVCM2VxyJW4x4GJ
    xml-conduit-1.9.1.4-9Ue8Gt5Yji0CMOePUH19S8

haddock-interfaces:   /usr/share/doc/haskell-citeproc/html/citeproc.haddock
haddock-html:         /usr/share/doc/haskell-citeproc/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-citeproc-0.8.1-189-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-citeproc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 citeproc
version:              0.8.1
visibility:           public
id:                   citeproc-0.8.1-8ORvKVIA6kZIcPECKW43Dg
key:                  citeproc-0.8.1-8ORvKVIA6kZIcPECKW43Dg
license:              BSD-2-Clause
copyright:            2020 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Generates citations and bibliography from CSL styles.
description:
    citeproc parses CSL style files and uses them to
    generate a list of formatted citations and bibliography
    entries.  For more information about CSL, see
    <https://citationstyles.org/>.

category:             Text
abi:                  27440d270be3a4cbabefd4f897dc877a
exposed:              True
exposed-modules:
    Citeproc Citeproc.CaseTransform Citeproc.CslJson Citeproc.Eval
    Citeproc.Locale Citeproc.Pandoc Citeproc.Style Citeproc.Types

hidden-modules:       Citeproc.Element Citeproc.Data Citeproc.Unicode
import-dirs:          /usr/lib/ghc-9.4.8/site-local/citeproc-0.8.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/citeproc-0.8.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/citeproc-0.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-citeproc
hs-libraries:         HSciteproc-0.8.1-8ORvKVIA6kZIcPECKW43Dg
depends:
    aeson-2.1.2.1-BB6MQBhtmtsAO1zPoxRUji
    attoparsec-0.14.4-6t7vY6Q8UUxCr7xgApY0J0 base-4.17.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-KKJyu9JGFWV4kYAUCco28N
    containers-0.6.7 data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY filepath-1.4.2.2
    pandoc-types-1.23.1-I50ZHyXzj5LIaAi8j1mqv5
    safe-0.3.21-EVxU3guTVsn44meiNlrghU
    scientific-0.3.7.0-BwEO4QQ4poVHhQfhShWbCU text-2.0.2
    text-icu-0.8.0.5-2r7xk6LESdq60514Vgauit transformers-0.5.6.2
    unicode-collation-0.1.3.6-DrJxI1kjQML5j1gAwZtrv
    uniplate-1.6.13-EDMgBXQkmI8BXGn3V0USux
    vector-0.13.2.0-7SxE3dSPVCM2VxyJW4x4GJ
    xml-conduit-1.9.1.4-Ak47fO6N9ywJGCVHmk6gCa

haddock-interfaces:   /usr/share/doc/haskell-citeproc/html/citeproc.haddock
haddock-html:         /usr/share/doc/haskell-citeproc/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
